@@ -48,7 +48,7 @@ error "gperf generated tables don't work with this execution character set. Plea
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: compat.c,v 1.3 2005/11/22 23:11:20 luks Exp $
+ * $Id: compat.c,v 1.4 2006/01/15 15:54:46 luks Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -78,7 +78,7 @@ error "gperf generated tables don't work with this execution character set. Plea
 static id3_compat_func_t translate_TCON;
 static id3_compat_func_t translate_APIC;
 
-#define TOTAL_KEYWORDS 73
+#define TOTAL_KEYWORDS 72
 #define MIN_WORD_LENGTH 3
 #define MAX_WORD_LENGTH 4
 #define MIN_HASH_VALUE 6
@@ -103,8 +103,8 @@ hash (str, len)
       128, 128, 128, 128, 128, 128, 128, 128, 128, 128,
       128, 128, 128, 128, 128, 128, 128, 128, 128, 128,
       128, 128, 128, 128, 128, 128, 128, 128, 128, 128,
-      128, 128, 128, 128, 128, 128, 128, 128, 128,  64,
-       58,  20,  15, 128, 128, 128, 128, 128, 128, 128,
+      128, 128, 128, 128, 128, 128, 128, 128, 128,  58,
+       53,  20,  15, 128, 128, 128, 128, 128, 128, 128,
       128, 128, 128, 128, 128,  10,  18,   3,   6,   1,
        47,   0, 128,  42,  62,  30,  31,   0,  19,  52,
        10,  24,   8,  30,   5,   3,  30,   8,  25,  47,
@@ -157,151 +157,221 @@ id3_compat_lookup (str, len)
   static const struct id3_compat wordlist[] =
     {
 #line 98 "compat.gperf"
-      {"TLE",  EQ(TLEN)  /* Length */},
+      {"TLE",  EQ(TLEN)  /* Length */
+},
 #line 69 "compat.gperf"
-      {"ETC",  EQ(ETCO)  /* Event timing codes */},
+      {"ETC",  EQ(ETCO)  /* Event timing codes */
+},
 #line 127 "compat.gperf"
-      {"ULT",  EQ(USLT)  /* Unsynchronised lyric/text transcription */},
+      {"ULT",  EQ(USLT)  /* Unsynchronised lyric/text transcription */
+},
 #line 124 "compat.gperf"
-      {"TYE",  OBSOLETE  /* Year [obsolete] */},
+      {"TYE",  OBSOLETE  /* Year [obsolete] */
+},
 #line 93 "compat.gperf"
-      {"TFT",  EQ(TFLT)  /* File type */},
+      {"TFT",  EQ(TFLT)  /* File type */
+},
 #line 85 "compat.gperf"
-      {"TCM",  EQ(TCOM)  /* Composer */},
+      {"TCM",  EQ(TCOM)  /* Composer */
+},
 #line 67 "compat.gperf"
-      {"EQU",  OBSOLETE  /* Equalization [obsolete] */},
+      {"EQU",  OBSOLETE  /* Equalization [obsolete] */
+},
 #line 64 "compat.gperf"
-      {"COM",  EQ(COMM)  /* Comments */},
+      {"COM",  EQ(COMM)  /* Comments */
+},
 #line 131 "compat.gperf"
-      {"WCM",  EQ(WCOM)  /* Commercial information */},
+      {"WCM",  EQ(WCOM)  /* Commercial information */
+},
 #line 97 "compat.gperf"
-      {"TLA",  EQ(TLAN)  /* Language(s) */},
+      {"TLA",  EQ(TLAN)  /* Language(s) */
+},
 #line 89 "compat.gperf"
-      {"TDA",  OBSOLETE  /* Date [obsolete] */},
+      {"TDA",  OBSOLETE  /* Date [obsolete] */
+},
 #line 125 "compat.gperf"
-      {"TYER", OBSOLETE  /* Year [obsolete] */},
+      {"TYER", OBSOLETE  /* Year [obsolete] */
+},
 #line 84 "compat.gperf"
-      {"TBP",  EQ(TBPM)  /* BPM (beats per minute) */},
+      {"TBP",  EQ(TBPM)  /* BPM (beats per minute) */
+},
 #line 88 "compat.gperf"
-      {"TCR",  EQ(TCOP)  /* Copyright message */},
+      {"TCR",  EQ(TCOP)  /* Copyright message */
+},
 #line 105 "compat.gperf"
-      {"TOT",  EQ(TOAL)  /* Original album/movie/show title */},
+      {"TOT",  EQ(TOAL)  /* Original album/movie/show title */
+},
 #line 90 "compat.gperf"
-      {"TDAT", OBSOLETE  /* Date [obsolete] */},
+      {"TDAT", OBSOLETE  /* Date [obsolete] */
+},
 #line 68 "compat.gperf"
-      {"EQUA", OBSOLETE  /* Equalization [obsolete] */},
+      {"EQUA", OBSOLETE  /* Equalization [obsolete] */
+},
 #line 103 "compat.gperf"
-      {"TOR",  EQ(TDOR)  /* Original release year [obsolete] */},
+      {"TOR",  EQ(TDOR)  /* Original release year [obsolete] */
+},
 #line 132 "compat.gperf"
-      {"WCP",  EQ(WCOP)  /* Copyright/legal information */},
+      {"WCP",  EQ(WCOP)  /* Copyright/legal information */
+},
 #line 100 "compat.gperf"
-      {"TOA",  EQ(TOPE)  /* Original artist(s)/performer(s) */},
+      {"TOA",  EQ(TOPE)  /* Original artist(s)/performer(s) */
+},
 #line 79 "compat.gperf"
-      {"RVA",  OBSOLETE  /* Relative volume adjustment [obsolete] */},
+      {"RVA",  OBSOLETE  /* Relative volume adjustment [obsolete] */
+},
 #line 121 "compat.gperf"
-      {"TT3",  EQ(TIT3)  /* Subtitle/description refinement */},
+      {"TT3",  EQ(TIT3)  /* Subtitle/description refinement */
+},
 #line 99 "compat.gperf"
-      {"TMT",  EQ(TMED)  /* Media type */},
+      {"TMT",  EQ(TMED)  /* Media type */
+},
 #line 77 "compat.gperf"
-      {"POP",  EQ(POPM)  /* Popularimeter */},
+      {"POP",  EQ(POPM)  /* Popularimeter */
+},
 #line 75 "compat.gperf"
-      {"MLL",  EQ(MLLT)  /* MPEG location lookup table */},
+      {"MLL",  EQ(MLLT)  /* MPEG location lookup table */
+},
 #line 80 "compat.gperf"
-      {"RVAD", OBSOLETE  /* Relative volume adjustment [obsolete] */},
+      {"RVAD", OBSOLETE  /* Relative volume adjustment [obsolete] */
+},
 #line 66 "compat.gperf"
-      {"CRM",  OBSOLETE  /* Encrypted meta frame [obsolete] */},
+      {"CRM",  OBSOLETE  /* Encrypted meta frame [obsolete] */
+},
 #line 129 "compat.gperf"
-      {"WAR",  EQ(WOAR)  /* Official artist/performer webpage */},
+      {"WAR",  EQ(WOAR)  /* Official artist/performer webpage */
+},
 #line 81 "compat.gperf"
-      {"SLT",  EQ(SYLT)  /* Synchronised lyric/text */},
+      {"SLT",  EQ(SYLT)  /* Synchronised lyric/text */
+},
 #line 82 "compat.gperf"
-      {"STC",  EQ(SYTC)  /* Synchronised tempo codes */},
+      {"STC",  EQ(SYTC)  /* Synchronised tempo codes */
+},
 #line 96 "compat.gperf"
-      {"TKE",  EQ(TKEY)  /* Initial key */},
+      {"TKE",  EQ(TKEY)  /* Initial key */
+},
 #line 112 "compat.gperf"
-      {"TRC",  EQ(TSRC)  /* ISRC (international standard recording code) */},
+      {"TRC",  EQ(TSRC)  /* ISRC (international standard recording code) */
+},
 #line 110 "compat.gperf"
-      {"TPA",  EQ(TPOS)  /* Part of a set */},
+      {"TPA",  EQ(TPOS)  /* Part of a set */
+},
 #line 118 "compat.gperf"
-      {"TSS",  EQ(TSSE)  /* Software/hardware and settings used for encoding */},
+      {"TSS",  EQ(TSSE)  /* Software/hardware and settings used for encoding */
+},
 #line 113 "compat.gperf"
-      {"TRD",  OBSOLETE  /* Recording dates [obsolete] */},
+      {"TRD",  OBSOLETE  /* Recording dates [obsolete] */
+},
 #line 65 "compat.gperf"
-      {"CRA",  EQ(AENC)  /* Audio encryption */},
+      {"CRA",  EQ(AENC)  /* Audio encryption */
+},
 #line 109 "compat.gperf"
-      {"TP4",  EQ(TPE4)  /* Interpreted, remixed, or otherwise modified by */},
+      {"TP4",  EQ(TPE4)  /* Interpreted, remixed, or otherwise modified by */
+},
 #line 126 "compat.gperf"
-      {"UFI",  EQ(UFID)  /* Unique file identifier */},
+      {"UFI",  EQ(UFID)  /* Unique file identifier */
+},
 #line 102 "compat.gperf"
-      {"TOL",  EQ(TOLY)  /* Original lyricist(s)/text writer(s) */},
+      {"TOL",  EQ(TOLY)  /* Original lyricist(s)/text writer(s) */
+},
 #line 111 "compat.gperf"
-      {"TPB",  EQ(TPUB)  /* Publisher */},
+      {"TPB",  EQ(TPUB)  /* Publisher */
+},
 #line 74 "compat.gperf"
-      {"MCI",  EQ(MCDI)  /* Music CD identifier */},
+      {"MCI",  EQ(MCDI)  /* Music CD identifier */
+},
 #line 108 "compat.gperf"
-      {"TP3",  EQ(TPE3)  /* Conductor/performer refinement */},
+      {"TP3",  EQ(TPE3)  /* Conductor/performer refinement */
+},
 #line 133 "compat.gperf"
-      {"WPB",  EQ(WPUB)  /* Publishers official webpage */},
+      {"WPB",  EQ(WPUB)  /* Publishers official webpage */
+},
 #line 114 "compat.gperf"
-      {"TRDA", OBSOLETE  /* Recording dates [obsolete] */},
+      {"TRDA", OBSOLETE  /* Recording dates [obsolete] */
+},
 #line 116 "compat.gperf"
-      {"TSI",  OBSOLETE  /* Size [obsolete] */},
+      {"TSI",  OBSOLETE  /* Size [obsolete] */
+},
 #line 91 "compat.gperf"
-      {"TDY",  EQ(TDLY)  /* Playlist delay */},
+      {"TDY",  EQ(TDLY)  /* Playlist delay */
+},
 #line 83 "compat.gperf"
-      {"TAL",  EQ(TALB)  /* Album/movie/show title */},
+      {"TAL",  EQ(TALB)  /* Album/movie/show title */
+},
 #line 117 "compat.gperf"
-      {"TSIZ", OBSOLETE  /* Size [obsolete] */},
+      {"TSIZ", OBSOLETE  /* Size [obsolete] */
+},
 #line 130 "compat.gperf"
-      {"WAS",  EQ(WOAS)  /* Official audio source webpage */},
+      {"WAS",  EQ(WOAS)  /* Official audio source webpage */
+},
 #line 122 "compat.gperf"
-      {"TXT",  EQ(TEXT)  /* Lyricist/text writer */},
+      {"TXT",  EQ(TEXT)  /* Lyricist/text writer */
+},
 #line 63 "compat.gperf"
-      {"CNT",  EQ(PCNT)  /* Play counter */},
-#line 101 "compat.gperf"
-      {"TOF",  EQ(TOFN)  /* Original filename */},
-#line 86 "compat.gperf"
-      {"TCO",  TX(TCON)  /* Content type */},
-#line 115 "compat.gperf"
-      {"TRK",  EQ(TRCK)  /* Track number/position in set */},
+      {"CNT",  EQ(PCNT)  /* Play counter */
+},
 #line 120 "compat.gperf"
-      {"TT2",  EQ(TIT2)  /* Title/songname/content description */},
-#line 94 "compat.gperf"
-      {"TIM",  OBSOLETE  /* Time [obsolete] */},
-#line 95 "compat.gperf"
-      {"TIME", OBSOLETE  /* Time [obsolete] */},
-#line 104 "compat.gperf"
-      {"TORY", EQ(TDOR)  /* Original release year [obsolete] */},
-#line 92 "compat.gperf"
-      {"TEN",  EQ(TENC)  /* Encoded by */},
+      {"TT2",  EQ(TIT2)  /* Title/songname/content description */
+},
+#line 101 "compat.gperf"
+      {"TOF",  EQ(TOFN)  /* Original filename */
+},
+#line 86 "compat.gperf"
+      {"TCO",  EQ(TCON)  /* Content type */
+},
+#line 115 "compat.gperf"
+      {"TRK",  EQ(TRCK)  /* Track number/position in set */
+},
 #line 119 "compat.gperf"
-      {"TT1",  EQ(TIT1)  /* Content group description */},
+      {"TT1",  EQ(TIT1)  /* Content group description */
+},
+#line 94 "compat.gperf"
+      {"TIM",  OBSOLETE  /* Time [obsolete] */
+},
+#line 95 "compat.gperf"
+      {"TIME", OBSOLETE  /* Time [obsolete] */
+},
+#line 104 "compat.gperf"
+      {"TORY", EQ(TDOR)  /* Original release year [obsolete] */
+},
+#line 92 "compat.gperf"
+      {"TEN",  EQ(TENC)  /* Encoded by */
+},
 #line 128 "compat.gperf"
-      {"WAF",  EQ(WOAF)  /* Official audio file webpage */},
+      {"WAF",  EQ(WOAF)  /* Official audio file webpage */
+},
 #line 76 "compat.gperf"
-      {"PIC",  TX(APIC)  /* Attached picture */},
+      {"PIC",  TX(APIC)  /* Attached picture */
+},
 #line 123 "compat.gperf"
-      {"TXX",  EQ(TXXX)  /* User defined text information frame */},
+      {"TXX",  EQ(TXXX)  /* User defined text information frame */
+},
 #line 134 "compat.gperf"
-      {"WXX",  EQ(WXXX)  /* User defined URL link frame */},
-#line 87 "compat.gperf"
-      {"TCON", TX(TCON)  /* Content type */},
-#line 78 "compat.gperf"
-      {"REV",  EQ(RVRB)  /* Reverb */},
+      {"WXX",  EQ(WXXX)  /* User defined URL link frame */
+},
 #line 107 "compat.gperf"
-      {"TP2",  EQ(TPE2)  /* Band/orchestra/accompaniment */},
+      {"TP2",  EQ(TPE2)  /* Band/orchestra/accompaniment */
+},
+#line 78 "compat.gperf"
+      {"REV",  EQ(RVRB)  /* Reverb */
+},
 #line 106 "compat.gperf"
-      {"TP1",  EQ(TPE1)  /* Lead performer(s)/soloist(s) */},
+      {"TP1",  EQ(TPE1)  /* Lead performer(s)/soloist(s) */
+},
 #line 62 "compat.gperf"
-      {"BUF",  EQ(RBUF)  /* Recommended buffer size */},
+      {"BUF",  EQ(RBUF)  /* Recommended buffer size */
+},
 #line 71 "compat.gperf"
-      {"IPL",  EQ(TIPL)  /* Involved people list */},
+      {"IPL",  EQ(TIPL)  /* Involved people list */
+},
 #line 70 "compat.gperf"
-      {"GEO",  EQ(GEOB)  /* General encapsulated object */},
+      {"GEO",  EQ(GEOB)  /* General encapsulated object */
+},
 #line 73 "compat.gperf"
-      {"LNK",  EQ(LINK)  /* Linked information */},
+      {"LNK",  EQ(LINK)  /* Linked information */
+},
 #line 72 "compat.gperf"
-      {"IPLS", EQ(TIPL)  /* Involved people list */}
+      {"IPLS", EQ(TIPL)  /* Involved people list */
+}
     };
 
   static const short lookup[] =
@@ -310,12 +380,12 @@ id3_compat_lookup (str, len)
        8,  9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, -1,
       21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34,
       -1, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47,
-      48, 49, -1, -1, 50, -1, 51, 52, -1, 53, 54, 55, 56, -1,
-      57, 58, 59, 60, -1, 61, -1, 62, -1, -1, 63, -1, 64, -1,
-      -1, 65, -1, 66, -1, -1, -1, -1, -1, 67, -1, 68, -1, 69,
+      48, 49, -1, -1, 50, 51, 52, 53, -1, 54, 55, 56, 57, -1,
+      58, 59, -1, 60, -1, 61, -1, 62, -1, -1, 63, -1, 64, -1,
+      -1, 65, -1, 66, -1, -1, -1, -1, -1, -1, -1, 67, -1, 68,
+      -1, 69, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, 70, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, 71, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, 72
+      -1, 71
     };
 
   if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH)
